==> empire-4.2.21.tar.gz: empire-4.2.21/src/lib/update/removewants.c <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2005, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See the "LEGAL", "LICENSE", "CREDITS" and "README" files for all the
 *  related information and legal notices. It is expected that any future
 *  projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  removewants.c: Remove the "I want an update" flag.
 * 
 *  Known contributors to this file:
 *     
 */

#include <stdio.h>
#include <ctype.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <errno.h>
#include "misc.h"
#include "nat.h"
#include "file.h"
#include "update.h"

int
update_removewants(void)
{
    natid cn;
    struct natstr *natp;

    for (cn = 0; NULL != (natp = getnatp(cn)); cn++) {
	if ((natp->nat_stat & STAT_INUSE) &&
	    (natp->nat_update & WUPD_WANT) == 0) {
	    natp->nat_missed++;
	}
	natp->nat_update = natp->nat_stat & ~WUPD_WANT;
    }
    return 0;
}

==> empire-4.3.8.tar.gz: empire-4.3.8/src/lib/update/removewants.c <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2006, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See files README, COPYING and CREDITS in the root of the source
 *  tree for related information and legal notices.  It is expected
 *  that future projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  removewants.c: Remove the "I want an update" flag.
 * 
 *  Known contributors to this file:
 *     
 */

#include <config.h>

#include "update.h"

int
update_removewants(void)
{
    natid cn;
    struct natstr *natp;

    for (cn = 0; NULL != (natp = getnatp(cn)); cn++) {
	if ((natp->nat_stat != STAT_UNUSED) &&
	    (natp->nat_update & WUPD_WANT) == 0) {
	    natp->nat_missed++;
	}
	natp->nat_update &= ~WUPD_WANT;
    }
    return 0;
}
